/*******************************************************************************
* Copyright (c) 2006 IONA Technologies PLC
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
* 
* Contributors:
*     IONA Technologies PLC - initial API and implementation
*******************************************************************************/
package org.eclipse.stp.sc.jaxws.workspace;

import java.util.ArrayList;
import java.util.Arrays;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.IProjectNature;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.stp.sc.jaxws.ScJaxWsResources;

/**
 * define a java first oriented nature as well as the necessary lifecycle methods to manage it
 */
public class ScWsdlFirstNature implements IProjectNature {

	public static final String NATURE_ID = "org.eclipse.stp.sc.jaxws.wsdlFirstNature";
    
    //private static final LoggingProxy LOG = LoggingProxy.getlogger(ScWsdlJavaFirstNature.class);
    
    private IProject theProject;
    
    public void configure() throws CoreException {
    }
    
    public void deconfigure() throws CoreException {
    }
    

    public IProject getProject() {
        return theProject;
    }

    public void setProject(IProject value) {
        this.theProject = value;
    }

    public static void addToProject(IProject project) throws CoreException {
        if (!project.hasNature(ScNature.NATURE_ID)) {
            MessageDialog.openWarning(null,
                                      ScJaxWsResources.getString("ScWsdlFisrtNature.no.sc.dialog.title"),
                                      ScJaxWsResources.getString("ScWsdlFisrtNature.no.sc.dialog.message"));
            return; 
        }
        
        //add java first nature
        if (!project.hasNature(NATURE_ID)) {
            IProjectDescription desc = project.getDescription();
            String[] natures = desc.getNatureIds();
            String[] newNatures = new String[natures.length + 1];
			System.arraycopy(natures, 0, newNatures, 1, natures.length);
			newNatures[0] = NATURE_ID;
            desc.setNatureIds(newNatures);
            project.setDescription(desc, null);
        }
    }

    public static void removeFromProject(IProject project) throws CoreException {
        if (project.hasNature(ScNature.NATURE_ID)) {
            if (project.hasNature(NATURE_ID)) {
                IProjectDescription desc = project.getDescription();
                String[] natures = desc.getNatureIds();
                ArrayList<String> newNatures = new ArrayList<String>(Arrays.asList(natures));
                newNatures.remove(newNatures.indexOf(NATURE_ID));
                desc.setNatureIds(newNatures.toArray(new String[newNatures.size()]));
                project.setDescription(desc, null);
            }
        }
    }

    public static boolean hasNature(IProject aProject) throws CoreException {
    	return aProject.hasNature(NATURE_ID);
        
    }
}
